@@ -6,3 +6,5 @@ from procuret.data.order import Order
 from procuret.ancillary.entity_headline import EntityHeadline
 from procuret import errors
 from procuret.version import VERSION
+from procuret.term_rate.term_rate import TermRate
+from procuret.term_rate.group import TermRateGroup
