@@ -27,7 +27,8 @@ if '--last' in sys.argv[1:]:
 
 
 TESTS = [
-    cases.ExerciseInstalmentLink
+    cases.ExerciseInstalmentLink,
+    cases.ExerciseTermRateGroup
 ]
 
 
